/*******************************************************************************
 * Licensed Materials - Property of IBM
 * Copyright IBM Corp. 2009, 2010.  All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("deploy.rmps.properties.ConstraintsSection");

dojo.require("dijit._Widget");
dojo.require("dojo.i18n");

dojo.require("rmps.app.core.util");

dojo.require("jazz.ui.StyledTable");
dojo.require("jazz.ui.ResourceLink");

dojo.requireLocalization("deploy.rmps.properties", "ConstraintsSectionMessages");
	
var messages = dojo.i18n.getLocalization("deploy.rmps.properties", "ConstraintsSectionMessages");

dojo.declare("deploy.rmps.properties.ConstraintsSection", dijit._Widget, {
	
	"class": "deploy-rmps-properties-constraintsSection",
	
	// mixin properties
	/*
	 * constraints: [
	 *                {
	 *                    category: "",
	 *                    value: { // or array
	 *                               label: "",
	 *                               uri: "" || null
	 *                           }
	 *                }
	 *            ]
	 */
	
	postCreate: function() {
		this.containerNode = this.domNode;
		
		var columns = [
			{
				label: messages.column_value,
			}
		];
		
		var table = new jazz.ui.StyledTable({
			columns: columns	
		});
		
		if (this.tableData) {
			
			var lastCategory = null;
			
			for (var i = 0, data; data = this.tableData[i]; ++i) {
				// assume data is ordered by category from the server
				if (data.category !== lastCategory) {
					// add category
					table.tbody.appendChild(this._createCategoryRow(data.category));
					lastCategory = data.category;
				}
				table.tbody.appendChild(this._createLinkRow(data));
			}
		}
		
		this.domNode.appendChild(table.domNode);
	},
	
	_createCategoryRow: function(category) {
		var tr = dojo.create("tr");
		var categoryCell = dojo.create("td", {"class": "category"}, tr);
		categoryCell.appendChild(dojo.doc.createTextNode(category));
		
		var emptyCell = dojo.create("td", null, tr);
		emptyCell.innerHTML = "&nbsp;";
		
		return tr;
	},
	
	_createLinkRow: function(rowData) {
		var tr = dojo.create("tr");
		var valueCell = dojo.create("td", {"class": "value"}, tr);
		var value = rowData.value;
		if (value) {
			if (dojo.isArray(value)) {
				if (value.length > 0) {
					for (var i = 0; i < value.length; ++i) {
						if (i != 0) {
							valueCell.appendChild(dojo.create("br"));
						}
						this._populateValueCell(valueCell, value[i]);
					}
				} else {
					valueCell.innerHTML = "&nbsp;";
				}
			} else {
				this._populateValueCell(valueCell, value);
			}
		} else {
			valueCell.innerHTML = "&nbsp;";
		}
		
		return tr;
	},
	
	_populateValueCell: function(valueCell, value) {
		if (value.label != null && value.label.length > 0) {
			valueCell.appendChild(dojo.doc.createTextNode(value.label));
			
		} else {
			valueCell.innerHTML += "&nbsp;";
			return false;
		}
		return true;
	}
});

})();